@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Get XML.
 has xml => (
@@ -117,7 +117,6 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
 
  # Pragmas.
  use strict;
- use utf8;
  use warnings;
 
  # Modules.
@@ -135,6 +134,42 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
  # Output like:
  # XML file: .*/prague-map.xml
 
+=head1 EXAMPLE3
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Map::Tube::GraphViz;
+ use Map::Tube::GraphViz::Utils qw(node_color_without_label);
+ use Map::Tube::Prague;
+
+ # Object.
+ my $obj = Map::Tube::Prague->new;
+
+ # GraphViz object.
+ my $g = Map::Tube::GraphViz->new(
+         'callback_node' => \&node_color_without_label,
+         'driver' => 'neato',
+         'tube' => $obj,
+ ); 
+
+ # Get graph to file.
+ $g->graph('Prague.png');
+
+ # Print file.
+ system "ls -l Prague.png";
+
+ # Output like:
+ # -rw-r--r-- 1 skim skim 292500 Dec 21 17:25 Prague.png
+
+=begin html
+
+<img src="images/Prague.png" alt="Pražské metro" width="300px" height="300px" />
+
+=end html
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -145,21 +180,29 @@ L<namespace::clean>.
 =head1 SEE ALSO
 
 L<Map::Tube>,
+L<Map::Tube::GraphViz>,
+L<Map::Tube::Text::Table>.
+
 L<Map::Tube::Barcelona>,
 L<Map::Tube::Berlin>,
 L<Map::Tube::Bucharest>,
 L<Map::Tube::Delhi>,
+L<Map::Tube::Dnipropetrovsk>,
 L<Map::Tube::Kazan>,
 L<Map::Tube::Kharkiv>,
 L<Map::Tube::Kiev>,
 L<Map::Tube::London>,
 L<Map::Tube::Minsk>,
 L<Map::Tube::Moscow>,
+L<Map::Tube::Novosibirsk>,
 L<Map::Tube::NYC>,
+L<Map::Tube::SaintPetersburg>,
 L<Map::Tube::Samara>,
 L<Map::Tube::Sofia>,
+L<Map::Tube::Tbilisi>,
 L<Map::Tube::Tokyo>,
-L<Map::Tube::Warsaw>.
+L<Map::Tube::Warsaw>,
+L<Map::Tube::Yekaterinburg>.
 
 =head1 REPOSITORY
 
@@ -179,6 +222,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
